# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BizTypeArgs', 'BizType']

@pulumi.input_type
class BizTypeArgs:
    def __init__(__self__, *,
                 biz_type_name: pulumi.Input[str],
                 biz_type_import: Optional[pulumi.Input[str]] = None,
                 cite_template: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 industry_info: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a BizType resource.
        :param pulumi.Input[str] biz_type_name: The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        :param pulumi.Input[str] biz_type_import: The name of the existing business scenario that was imported from when the business scenario was created.
        :param pulumi.Input[bool] cite_template: Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        :param pulumi.Input[str] description: The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        :param pulumi.Input[str] industry_info: The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        pulumi.set(__self__, "biz_type_name", biz_type_name)
        if biz_type_import is not None:
            pulumi.set(__self__, "biz_type_import", biz_type_import)
        if cite_template is not None:
            pulumi.set(__self__, "cite_template", cite_template)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if industry_info is not None:
            pulumi.set(__self__, "industry_info", industry_info)

    @property
    @pulumi.getter(name="bizTypeName")
    def biz_type_name(self) -> pulumi.Input[str]:
        """
        The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        """
        return pulumi.get(self, "biz_type_name")

    @biz_type_name.setter
    def biz_type_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "biz_type_name", value)

    @property
    @pulumi.getter(name="bizTypeImport")
    def biz_type_import(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the existing business scenario that was imported from when the business scenario was created.
        """
        return pulumi.get(self, "biz_type_import")

    @biz_type_import.setter
    def biz_type_import(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type_import", value)

    @property
    @pulumi.getter(name="citeTemplate")
    def cite_template(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        """
        return pulumi.get(self, "cite_template")

    @cite_template.setter
    def cite_template(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cite_template", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="industryInfo")
    def industry_info(self) -> Optional[pulumi.Input[str]]:
        """
        The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        return pulumi.get(self, "industry_info")

    @industry_info.setter
    def industry_info(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "industry_info", value)


@pulumi.input_type
class _BizTypeState:
    def __init__(__self__, *,
                 biz_type_import: Optional[pulumi.Input[str]] = None,
                 biz_type_name: Optional[pulumi.Input[str]] = None,
                 cite_template: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 industry_info: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BizType resources.
        :param pulumi.Input[str] biz_type_import: The name of the existing business scenario that was imported from when the business scenario was created.
        :param pulumi.Input[str] biz_type_name: The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        :param pulumi.Input[bool] cite_template: Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        :param pulumi.Input[str] description: The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        :param pulumi.Input[str] industry_info: The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        if biz_type_import is not None:
            pulumi.set(__self__, "biz_type_import", biz_type_import)
        if biz_type_name is not None:
            pulumi.set(__self__, "biz_type_name", biz_type_name)
        if cite_template is not None:
            pulumi.set(__self__, "cite_template", cite_template)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if industry_info is not None:
            pulumi.set(__self__, "industry_info", industry_info)

    @property
    @pulumi.getter(name="bizTypeImport")
    def biz_type_import(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the existing business scenario that was imported from when the business scenario was created.
        """
        return pulumi.get(self, "biz_type_import")

    @biz_type_import.setter
    def biz_type_import(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type_import", value)

    @property
    @pulumi.getter(name="bizTypeName")
    def biz_type_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        """
        return pulumi.get(self, "biz_type_name")

    @biz_type_name.setter
    def biz_type_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type_name", value)

    @property
    @pulumi.getter(name="citeTemplate")
    def cite_template(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        """
        return pulumi.get(self, "cite_template")

    @cite_template.setter
    def cite_template(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cite_template", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="industryInfo")
    def industry_info(self) -> Optional[pulumi.Input[str]]:
        """
        The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        return pulumi.get(self, "industry_info")

    @industry_info.setter
    def industry_info(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "industry_info", value)


class BizType(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_type_import: Optional[pulumi.Input[str]] = None,
                 biz_type_name: Optional[pulumi.Input[str]] = None,
                 cite_template: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 industry_info: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Aligreen Biz Type resource.

        For information about Aligreen Biz Type and how to use it, see [What is Biz Type](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.aligreen.BizType("default",
            biz_type_name=name,
            description=name,
            cite_template=True,
            industry_info="社交-注册信息-昵称",
            biz_type_import="1")
        ```

        ## Import

        Aligreen Biz Type can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/bizType:BizType example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_type_import: The name of the existing business scenario that was imported from when the business scenario was created.
        :param pulumi.Input[str] biz_type_name: The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        :param pulumi.Input[bool] cite_template: Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        :param pulumi.Input[str] description: The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        :param pulumi.Input[str] industry_info: The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BizTypeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Aligreen Biz Type resource.

        For information about Aligreen Biz Type and how to use it, see [What is Biz Type](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform_example"
        default = alicloud.aligreen.BizType("default",
            biz_type_name=name,
            description=name,
            cite_template=True,
            industry_info="社交-注册信息-昵称",
            biz_type_import="1")
        ```

        ## Import

        Aligreen Biz Type can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/bizType:BizType example <id>
        ```

        :param str resource_name: The name of the resource.
        :param BizTypeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BizTypeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 biz_type_import: Optional[pulumi.Input[str]] = None,
                 biz_type_name: Optional[pulumi.Input[str]] = None,
                 cite_template: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 industry_info: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BizTypeArgs.__new__(BizTypeArgs)

            __props__.__dict__["biz_type_import"] = biz_type_import
            if biz_type_name is None and not opts.urn:
                raise TypeError("Missing required property 'biz_type_name'")
            __props__.__dict__["biz_type_name"] = biz_type_name
            __props__.__dict__["cite_template"] = cite_template
            __props__.__dict__["description"] = description
            __props__.__dict__["industry_info"] = industry_info
        super(BizType, __self__).__init__(
            'alicloud:aligreen/bizType:BizType',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            biz_type_import: Optional[pulumi.Input[str]] = None,
            biz_type_name: Optional[pulumi.Input[str]] = None,
            cite_template: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            industry_info: Optional[pulumi.Input[str]] = None) -> 'BizType':
        """
        Get an existing BizType resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] biz_type_import: The name of the existing business scenario that was imported from when the business scenario was created.
        :param pulumi.Input[str] biz_type_name: The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        :param pulumi.Input[bool] cite_template: Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        :param pulumi.Input[str] description: The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        :param pulumi.Input[str] industry_info: The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BizTypeState.__new__(_BizTypeState)

        __props__.__dict__["biz_type_import"] = biz_type_import
        __props__.__dict__["biz_type_name"] = biz_type_name
        __props__.__dict__["cite_template"] = cite_template
        __props__.__dict__["description"] = description
        __props__.__dict__["industry_info"] = industry_info
        return BizType(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bizTypeImport")
    def biz_type_import(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the existing business scenario that was imported from when the business scenario was created.
        """
        return pulumi.get(self, "biz_type_import")

    @property
    @pulumi.getter(name="bizTypeName")
    def biz_type_name(self) -> pulumi.Output[str]:
        """
        The name of the business scenario defined by the customer. It can contain no more than 32 characters in English, numbers, and underscores.
        """
        return pulumi.get(self, "biz_type_name")

    @property
    @pulumi.getter(name="citeTemplate")
    def cite_template(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to import the configuration of an industry template. Default value: false. Valid values: true: imports the configuration of an industry template. false: does not import the configuration of an industry template. If the value is true, you must specify the industryInfo parameter.
        """
        return pulumi.get(self, "cite_template")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the business scenario defined by the customer, which is a combination of Chinese and English, numbers, and underscores, and cannot exceed 32 characters.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="industryInfo")
    def industry_info(self) -> pulumi.Output[Optional[str]]:
        """
        The industry classification. Valid values: Social-Registration information-Profile picture Social-Registration information-Nickname Social-Registration information-Bio Social-Instant messaging-Chat Social-Instant messaging-Group chat Social-Instant messaging-Chat room Social-Forums&Communities-Post Social-Forums&Communities-Comment Social-Forums&Communities-Tag Social-Forums&Communities-Recommendation Multimedia-Registration information-Profile picture Multimedia-Registration information-Nickname Multimedia-Registration information-Bio Multimedia-Instant messaging-Chat Multimedia-Live streaming-Heading Multimedia-Live streaming-Cover Multimedia-Live streaming-Content Multimedia-Live streaming-Comment Multimedia-Online storage-Storage content Multimedia-Online storage-Shared content Gaming-Registration information-Nickname Gaming-Registration information-Profile picture Gaming-Registration information-Signature Gaming-Instant messaging-Chat Gaming-Instant messaging-Group chat Gaming-Instant messaging-Chat room Gaming-Forums&Communities-Post Gaming-Forums&Communities-Comment Gaming-Forums&Communities-Tag Gaming-Forums&Communities-Recommendation New retail-Goods-Heading New retail-Goods-Description Reading-Books-Title Reading-Books-Heading Reading-Books-Cover Reading-Books-Content Media-News content-News content Education-Registration information-Nickname Education-Registration information-Profile picture Education-Registration information-Bio Gaming-Instant messaging-Chat Gaming-Forums&Communities-Post Education-Forums&Communities-Comment Education-Forums&Communities-Tag Education-Forums&Communities-Recommendation Education-Customer service-Voice call Others
        """
        return pulumi.get(self, "industry_info")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VpcEndpointArgs', 'VpcEndpoint']

@pulumi.input_type
class VpcEndpointArgs:
    def __init__(__self__, *,
                 security_group_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 vpc_id: pulumi.Input[str],
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 endpoint_description: Optional[pulumi.Input[str]] = None,
                 endpoint_type: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 protected_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[str]] = None,
                 zone_private_ip_address_count: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a VpcEndpoint resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        :param pulumi.Input[str] vpc_id: The ID of the VPC to which the endpoint belongs.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
               - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
               - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        :param pulumi.Input[str] endpoint_description: The description of the endpoint.
        :param pulumi.Input[str] endpoint_type: The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        :param pulumi.Input[str] policy_document: RAM access policies.
        :param pulumi.Input[bool] protected_enabled: Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
               - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
               - **false (default)**: disables user authentication.
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[str] service_id: The ID of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] service_name: The name of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The list of tags.
        :param pulumi.Input[str] vpc_endpoint_name: The name of the endpoint.
        :param pulumi.Input[int] zone_private_ip_address_count: The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if endpoint_description is not None:
            pulumi.set(__self__, "endpoint_description", endpoint_description)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if protected_enabled is not None:
            pulumi.set(__self__, "protected_enabled", protected_enabled)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_endpoint_name is not None:
            pulumi.set(__self__, "vpc_endpoint_name", vpc_endpoint_name)
        if zone_private_ip_address_count is not None:
            pulumi.set(__self__, "zone_private_ip_address_count", zone_private_ip_address_count)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC to which the endpoint belongs.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
        - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="endpointDescription")
    def endpoint_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the endpoint.
        """
        return pulumi.get(self, "endpoint_description")

    @endpoint_description.setter
    def endpoint_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_description", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        RAM access policies.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="protectedEnabled")
    def protected_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
        - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
        - **false (default)**: disables user authentication.
        """
        return pulumi.get(self, "protected_enabled")

    @protected_enabled.setter
    def protected_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "protected_enabled", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The list of tags.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint.
        """
        return pulumi.get(self, "vpc_endpoint_name")

    @vpc_endpoint_name.setter
    def vpc_endpoint_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_endpoint_name", value)

    @property
    @pulumi.getter(name="zonePrivateIpAddressCount")
    def zone_private_ip_address_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        return pulumi.get(self, "zone_private_ip_address_count")

    @zone_private_ip_address_count.setter
    def zone_private_ip_address_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "zone_private_ip_address_count", value)


@pulumi.input_type
class _VpcEndpointState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 connection_status: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 endpoint_business_status: Optional[pulumi.Input[str]] = None,
                 endpoint_description: Optional[pulumi.Input[str]] = None,
                 endpoint_domain: Optional[pulumi.Input[str]] = None,
                 endpoint_type: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 protected_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 zone_private_ip_address_count: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering VpcEndpoint resources.
        :param pulumi.Input[int] bandwidth: The bandwidth of the endpoint connection.  1024 to 10240. Unit: Mbit/s. Note: The bandwidth of an endpoint connection is in the range of 100 to 10,240 Mbit/s. The default bandwidth is 1,024 Mbit/s. When the endpoint is connected to the endpoint service, the default bandwidth is the minimum bandwidth. In this case, the connection bandwidth range is 1,024 to 10,240 Mbit/s.
        :param pulumi.Input[str] connection_status: The state of the endpoint connection.
        :param pulumi.Input[str] create_time: The time when the endpoint was created.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
               - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
               - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        :param pulumi.Input[str] endpoint_business_status: The service state of the endpoint.
        :param pulumi.Input[str] endpoint_description: The description of the endpoint.
        :param pulumi.Input[str] endpoint_domain: The domain name of the endpoint.
        :param pulumi.Input[str] endpoint_type: The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        :param pulumi.Input[str] policy_document: RAM access policies.
        :param pulumi.Input[bool] protected_enabled: Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
               - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
               - **false (default)**: disables user authentication.
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        :param pulumi.Input[str] service_id: The ID of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] service_name: The name of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] status: The state of the endpoint.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The list of tags.
        :param pulumi.Input[str] vpc_endpoint_name: The name of the endpoint.
        :param pulumi.Input[str] vpc_id: The ID of the VPC to which the endpoint belongs.
        :param pulumi.Input[int] zone_private_ip_address_count: The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if connection_status is not None:
            pulumi.set(__self__, "connection_status", connection_status)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if endpoint_business_status is not None:
            pulumi.set(__self__, "endpoint_business_status", endpoint_business_status)
        if endpoint_description is not None:
            pulumi.set(__self__, "endpoint_description", endpoint_description)
        if endpoint_domain is not None:
            pulumi.set(__self__, "endpoint_domain", endpoint_domain)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if protected_enabled is not None:
            pulumi.set(__self__, "protected_enabled", protected_enabled)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if service_id is not None:
            pulumi.set(__self__, "service_id", service_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_endpoint_name is not None:
            pulumi.set(__self__, "vpc_endpoint_name", vpc_endpoint_name)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_private_ip_address_count is not None:
            pulumi.set(__self__, "zone_private_ip_address_count", zone_private_ip_address_count)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The bandwidth of the endpoint connection.  1024 to 10240. Unit: Mbit/s. Note: The bandwidth of an endpoint connection is in the range of 100 to 10,240 Mbit/s. The default bandwidth is 1,024 Mbit/s. When the endpoint is connected to the endpoint service, the default bandwidth is the minimum bandwidth. In this case, the connection bandwidth range is 1,024 to 10,240 Mbit/s.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="connectionStatus")
    def connection_status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the endpoint connection.
        """
        return pulumi.get(self, "connection_status")

    @connection_status.setter
    def connection_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_status", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the endpoint was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
        - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="endpointBusinessStatus")
    def endpoint_business_status(self) -> Optional[pulumi.Input[str]]:
        """
        The service state of the endpoint.
        """
        return pulumi.get(self, "endpoint_business_status")

    @endpoint_business_status.setter
    def endpoint_business_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_business_status", value)

    @property
    @pulumi.getter(name="endpointDescription")
    def endpoint_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the endpoint.
        """
        return pulumi.get(self, "endpoint_description")

    @endpoint_description.setter
    def endpoint_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_description", value)

    @property
    @pulumi.getter(name="endpointDomain")
    def endpoint_domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name of the endpoint.
        """
        return pulumi.get(self, "endpoint_domain")

    @endpoint_domain.setter
    def endpoint_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_domain", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[str]]:
        """
        The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        RAM access policies.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="protectedEnabled")
    def protected_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
        - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
        - **false (default)**: disables user authentication.
        """
        return pulumi.get(self, "protected_enabled")

    @protected_enabled.setter
    def protected_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "protected_enabled", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_id")

    @service_id.setter
    def service_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the endpoint.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The list of tags.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint.
        """
        return pulumi.get(self, "vpc_endpoint_name")

    @vpc_endpoint_name.setter
    def vpc_endpoint_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_endpoint_name", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC to which the endpoint belongs.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="zonePrivateIpAddressCount")
    def zone_private_ip_address_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        return pulumi.get(self, "zone_private_ip_address_count")

    @zone_private_ip_address_count.setter
    def zone_private_ip_address_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "zone_private_ip_address_count", value)


class VpcEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 endpoint_description: Optional[pulumi.Input[str]] = None,
                 endpoint_type: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 protected_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 zone_private_ip_address_count: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Private Link Vpc Endpoint resource.

        For information about Private Link Vpc Endpoint and how to use it, see [What is Vpc Endpoint](https://www.alibabacloud.com/help/en/privatelink/latest/api-privatelink-2020-04-15-createvpcendpoint).

        > **NOTE:** Available since v1.109.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        defaultb_fz_a4a = alicloud.vpc.Network("defaultbFzA4a",
            description="example-terraform",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        default1_ft_fr_p = alicloud.ecs.SecurityGroup("default1FTFrP",
            name=name,
            vpc_id=defaultb_fz_a4a.id)
        defaultjlj_y5_s = alicloud.ecs.SecurityGroup("defaultjljY5S",
            name=name,
            vpc_id=defaultb_fz_a4a.id)
        default_vpc_endpoint = alicloud.privatelink.VpcEndpoint("default",
            endpoint_description=name,
            vpc_endpoint_name=name,
            resource_group_id=default.ids[0],
            endpoint_type="Interface",
            vpc_id=defaultb_fz_a4a.id,
            service_name="com.aliyuncs.privatelink.ap-southeast-5.oss",
            dry_run=False,
            zone_private_ip_address_count=1,
            policy_document=json.dumps({
                "Version": "1",
                "Statement": [{
                    "Effect": "Allow",
                    "Action": ["*"],
                    "Resource": ["*"],
                    "Principal": "*",
                }],
            }),
            security_group_ids=[default1_ft_fr_p.id],
            service_id="epsrv-k1apjysze8u1l9t6uyg9",
            protected_enabled=False)
        ```

        ## Import

        Private Link Vpc Endpoint can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:privatelink/vpcEndpoint:VpcEndpoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
               - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
               - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        :param pulumi.Input[str] endpoint_description: The description of the endpoint.
        :param pulumi.Input[str] endpoint_type: The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        :param pulumi.Input[str] policy_document: RAM access policies.
        :param pulumi.Input[bool] protected_enabled: Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
               - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
               - **false (default)**: disables user authentication.
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        :param pulumi.Input[str] service_id: The ID of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] service_name: The name of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The list of tags.
        :param pulumi.Input[str] vpc_endpoint_name: The name of the endpoint.
        :param pulumi.Input[str] vpc_id: The ID of the VPC to which the endpoint belongs.
        :param pulumi.Input[int] zone_private_ip_address_count: The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Private Link Vpc Endpoint resource.

        For information about Private Link Vpc Endpoint and how to use it, see [What is Vpc Endpoint](https://www.alibabacloud.com/help/en/privatelink/latest/api-privatelink-2020-04-15-createvpcendpoint).

        > **NOTE:** Available since v1.109.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.resourcemanager.get_resource_groups()
        defaultb_fz_a4a = alicloud.vpc.Network("defaultbFzA4a",
            description="example-terraform",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        default1_ft_fr_p = alicloud.ecs.SecurityGroup("default1FTFrP",
            name=name,
            vpc_id=defaultb_fz_a4a.id)
        defaultjlj_y5_s = alicloud.ecs.SecurityGroup("defaultjljY5S",
            name=name,
            vpc_id=defaultb_fz_a4a.id)
        default_vpc_endpoint = alicloud.privatelink.VpcEndpoint("default",
            endpoint_description=name,
            vpc_endpoint_name=name,
            resource_group_id=default.ids[0],
            endpoint_type="Interface",
            vpc_id=defaultb_fz_a4a.id,
            service_name="com.aliyuncs.privatelink.ap-southeast-5.oss",
            dry_run=False,
            zone_private_ip_address_count=1,
            policy_document=json.dumps({
                "Version": "1",
                "Statement": [{
                    "Effect": "Allow",
                    "Action": ["*"],
                    "Resource": ["*"],
                    "Principal": "*",
                }],
            }),
            security_group_ids=[default1_ft_fr_p.id],
            service_id="epsrv-k1apjysze8u1l9t6uyg9",
            protected_enabled=False)
        ```

        ## Import

        Private Link Vpc Endpoint can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:privatelink/vpcEndpoint:VpcEndpoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VpcEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 endpoint_description: Optional[pulumi.Input[str]] = None,
                 endpoint_type: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 protected_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 service_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 vpc_endpoint_name: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 zone_private_ip_address_count: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcEndpointArgs.__new__(VpcEndpointArgs)

            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["endpoint_description"] = endpoint_description
            __props__.__dict__["endpoint_type"] = endpoint_type
            __props__.__dict__["policy_document"] = policy_document
            __props__.__dict__["protected_enabled"] = protected_enabled
            __props__.__dict__["resource_group_id"] = resource_group_id
            if security_group_ids is None and not opts.urn:
                raise TypeError("Missing required property 'security_group_ids'")
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["service_id"] = service_id
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc_endpoint_name"] = vpc_endpoint_name
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["zone_private_ip_address_count"] = zone_private_ip_address_count
            __props__.__dict__["bandwidth"] = None
            __props__.__dict__["connection_status"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["endpoint_business_status"] = None
            __props__.__dict__["endpoint_domain"] = None
            __props__.__dict__["status"] = None
        super(VpcEndpoint, __self__).__init__(
            'alicloud:privatelink/vpcEndpoint:VpcEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            connection_status: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            endpoint_business_status: Optional[pulumi.Input[str]] = None,
            endpoint_description: Optional[pulumi.Input[str]] = None,
            endpoint_domain: Optional[pulumi.Input[str]] = None,
            endpoint_type: Optional[pulumi.Input[str]] = None,
            policy_document: Optional[pulumi.Input[str]] = None,
            protected_enabled: Optional[pulumi.Input[bool]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            service_id: Optional[pulumi.Input[str]] = None,
            service_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            vpc_endpoint_name: Optional[pulumi.Input[str]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            zone_private_ip_address_count: Optional[pulumi.Input[int]] = None) -> 'VpcEndpoint':
        """
        Get an existing VpcEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The bandwidth of the endpoint connection.  1024 to 10240. Unit: Mbit/s. Note: The bandwidth of an endpoint connection is in the range of 100 to 10,240 Mbit/s. The default bandwidth is 1,024 Mbit/s. When the endpoint is connected to the endpoint service, the default bandwidth is the minimum bandwidth. In this case, the connection bandwidth range is 1,024 to 10,240 Mbit/s.
        :param pulumi.Input[str] connection_status: The state of the endpoint connection.
        :param pulumi.Input[str] create_time: The time when the endpoint was created.
        :param pulumi.Input[bool] dry_run: Specifies whether to perform only a dry run, without performing the actual request. Valid values:
               - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
               - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        :param pulumi.Input[str] endpoint_business_status: The service state of the endpoint.
        :param pulumi.Input[str] endpoint_description: The description of the endpoint.
        :param pulumi.Input[str] endpoint_domain: The domain name of the endpoint.
        :param pulumi.Input[str] endpoint_type: The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        :param pulumi.Input[str] policy_document: RAM access policies.
        :param pulumi.Input[bool] protected_enabled: Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
               - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
               - **false (default)**: disables user authentication.
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_group_ids: The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        :param pulumi.Input[str] service_id: The ID of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] service_name: The name of the endpoint service with which the endpoint is associated.
        :param pulumi.Input[str] status: The state of the endpoint.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: The list of tags.
        :param pulumi.Input[str] vpc_endpoint_name: The name of the endpoint.
        :param pulumi.Input[str] vpc_id: The ID of the VPC to which the endpoint belongs.
        :param pulumi.Input[int] zone_private_ip_address_count: The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcEndpointState.__new__(_VpcEndpointState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["connection_status"] = connection_status
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["endpoint_business_status"] = endpoint_business_status
        __props__.__dict__["endpoint_description"] = endpoint_description
        __props__.__dict__["endpoint_domain"] = endpoint_domain
        __props__.__dict__["endpoint_type"] = endpoint_type
        __props__.__dict__["policy_document"] = policy_document
        __props__.__dict__["protected_enabled"] = protected_enabled
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["service_id"] = service_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_endpoint_name"] = vpc_endpoint_name
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["zone_private_ip_address_count"] = zone_private_ip_address_count
        return VpcEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        The bandwidth of the endpoint connection.  1024 to 10240. Unit: Mbit/s. Note: The bandwidth of an endpoint connection is in the range of 100 to 10,240 Mbit/s. The default bandwidth is 1,024 Mbit/s. When the endpoint is connected to the endpoint service, the default bandwidth is the minimum bandwidth. In this case, the connection bandwidth range is 1,024 to 10,240 Mbit/s.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="connectionStatus")
    def connection_status(self) -> pulumi.Output[str]:
        """
        The state of the endpoint connection.
        """
        return pulumi.get(self, "connection_status")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The time when the endpoint was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to perform only a dry run, without performing the actual request. Valid values:
        - **true**: performs only a dry run. The system checks the request for potential issues, including missing parameter values, incorrect request syntax, and service limits. If the request fails the dry run, an error message is returned. If the request passes the dry run, the DryRunOperation error code is returned.
        - **false (default)**: performs a dry run and performs the actual request. If the request passes the dry run, a 2xx HTTP status code is returned and the operation is performed.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="endpointBusinessStatus")
    def endpoint_business_status(self) -> pulumi.Output[str]:
        """
        The service state of the endpoint.
        """
        return pulumi.get(self, "endpoint_business_status")

    @property
    @pulumi.getter(name="endpointDescription")
    def endpoint_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the endpoint.
        """
        return pulumi.get(self, "endpoint_description")

    @property
    @pulumi.getter(name="endpointDomain")
    def endpoint_domain(self) -> pulumi.Output[str]:
        """
        The domain name of the endpoint.
        """
        return pulumi.get(self, "endpoint_domain")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Output[str]:
        """
        The endpoint type. Only the value: Interface, indicating the Interface endpoint. You can add the service resource types of Application Load Balancer (ALB), Classic Load Balancer (CLB), and Network Load Balancer (NLB).
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> pulumi.Output[str]:
        """
        RAM access policies.
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="protectedEnabled")
    def protected_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to enable user authentication. This parameter is available in Security Token Service (STS) mode. Valid values:
        - **true**: enables user authentication. After user authentication is enabled, only the user who creates the endpoint can modify or delete the endpoint in STS mode.
        - **false (default)**: disables user authentication.
        """
        return pulumi.get(self, "protected_enabled")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        The ID of the security group that is associated with the endpoint ENI. The security group can be used to control data transfer between the VPC and the endpoint ENI.The endpoint can be associated with up to 10 security groups.
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[str]:
        """
        The name of the endpoint service with which the endpoint is associated.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The state of the endpoint.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        The list of tags.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcEndpointName")
    def vpc_endpoint_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the endpoint.
        """
        return pulumi.get(self, "vpc_endpoint_name")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC to which the endpoint belongs.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zonePrivateIpAddressCount")
    def zone_private_ip_address_count(self) -> pulumi.Output[int]:
        """
        The number of private IP addresses that are assigned to an elastic network interface (ENI) in each zone. Only 1 is returned.
        """
        return pulumi.get(self, "zone_private_ip_address_count")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceSlbConnAddrArgs',
    'InstanceSlbConnAddrArgsDict',
    'InstanceUiProxyConnAddrArgs',
    'InstanceUiProxyConnAddrArgsDict',
    'InstanceZkConnAddrArgs',
    'InstanceZkConnAddrArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceSlbConnAddrArgsDict(TypedDict):
        conn_addr: NotRequired[pulumi.Input[str]]
        """
        The Phoenix address.
        """
        conn_addr_port: NotRequired[pulumi.Input[str]]
        """
        The number of the port over which Phoenix connects to the instance.
        """
        net_type: NotRequired[pulumi.Input[str]]
        """
        The type of the network. Valid values:
        """
elif False:
    InstanceSlbConnAddrArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceSlbConnAddrArgs:
    def __init__(__self__, *,
                 conn_addr: Optional[pulumi.Input[str]] = None,
                 conn_addr_port: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] conn_addr: The Phoenix address.
        :param pulumi.Input[str] conn_addr_port: The number of the port over which Phoenix connects to the instance.
        :param pulumi.Input[str] net_type: The type of the network. Valid values:
        """
        if conn_addr is not None:
            pulumi.set(__self__, "conn_addr", conn_addr)
        if conn_addr_port is not None:
            pulumi.set(__self__, "conn_addr_port", conn_addr_port)
        if net_type is not None:
            pulumi.set(__self__, "net_type", net_type)

    @property
    @pulumi.getter(name="connAddr")
    def conn_addr(self) -> Optional[pulumi.Input[str]]:
        """
        The Phoenix address.
        """
        return pulumi.get(self, "conn_addr")

    @conn_addr.setter
    def conn_addr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr", value)

    @property
    @pulumi.getter(name="connAddrPort")
    def conn_addr_port(self) -> Optional[pulumi.Input[str]]:
        """
        The number of the port over which Phoenix connects to the instance.
        """
        return pulumi.get(self, "conn_addr_port")

    @conn_addr_port.setter
    def conn_addr_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr_port", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the network. Valid values:
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "net_type", value)


if not MYPY:
    class InstanceUiProxyConnAddrArgsDict(TypedDict):
        conn_addr: NotRequired[pulumi.Input[str]]
        """
        The Phoenix address.
        """
        conn_addr_port: NotRequired[pulumi.Input[str]]
        """
        The number of the port over which Phoenix connects to the instance.
        """
        net_type: NotRequired[pulumi.Input[str]]
        """
        The type of the network. Valid values:
        """
elif False:
    InstanceUiProxyConnAddrArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceUiProxyConnAddrArgs:
    def __init__(__self__, *,
                 conn_addr: Optional[pulumi.Input[str]] = None,
                 conn_addr_port: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] conn_addr: The Phoenix address.
        :param pulumi.Input[str] conn_addr_port: The number of the port over which Phoenix connects to the instance.
        :param pulumi.Input[str] net_type: The type of the network. Valid values:
        """
        if conn_addr is not None:
            pulumi.set(__self__, "conn_addr", conn_addr)
        if conn_addr_port is not None:
            pulumi.set(__self__, "conn_addr_port", conn_addr_port)
        if net_type is not None:
            pulumi.set(__self__, "net_type", net_type)

    @property
    @pulumi.getter(name="connAddr")
    def conn_addr(self) -> Optional[pulumi.Input[str]]:
        """
        The Phoenix address.
        """
        return pulumi.get(self, "conn_addr")

    @conn_addr.setter
    def conn_addr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr", value)

    @property
    @pulumi.getter(name="connAddrPort")
    def conn_addr_port(self) -> Optional[pulumi.Input[str]]:
        """
        The number of the port over which Phoenix connects to the instance.
        """
        return pulumi.get(self, "conn_addr_port")

    @conn_addr_port.setter
    def conn_addr_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr_port", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the network. Valid values:
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "net_type", value)


if not MYPY:
    class InstanceZkConnAddrArgsDict(TypedDict):
        conn_addr: NotRequired[pulumi.Input[str]]
        """
        The Phoenix address.
        """
        conn_addr_port: NotRequired[pulumi.Input[str]]
        """
        The number of the port over which Phoenix connects to the instance.
        """
        net_type: NotRequired[pulumi.Input[str]]
        """
        The type of the network. Valid values:
        """
elif False:
    InstanceZkConnAddrArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceZkConnAddrArgs:
    def __init__(__self__, *,
                 conn_addr: Optional[pulumi.Input[str]] = None,
                 conn_addr_port: Optional[pulumi.Input[str]] = None,
                 net_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] conn_addr: The Phoenix address.
        :param pulumi.Input[str] conn_addr_port: The number of the port over which Phoenix connects to the instance.
        :param pulumi.Input[str] net_type: The type of the network. Valid values:
        """
        if conn_addr is not None:
            pulumi.set(__self__, "conn_addr", conn_addr)
        if conn_addr_port is not None:
            pulumi.set(__self__, "conn_addr_port", conn_addr_port)
        if net_type is not None:
            pulumi.set(__self__, "net_type", net_type)

    @property
    @pulumi.getter(name="connAddr")
    def conn_addr(self) -> Optional[pulumi.Input[str]]:
        """
        The Phoenix address.
        """
        return pulumi.get(self, "conn_addr")

    @conn_addr.setter
    def conn_addr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr", value)

    @property
    @pulumi.getter(name="connAddrPort")
    def conn_addr_port(self) -> Optional[pulumi.Input[str]]:
        """
        The number of the port over which Phoenix connects to the instance.
        """
        return pulumi.get(self, "conn_addr_port")

    @conn_addr_port.setter
    def conn_addr_port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "conn_addr_port", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the network. Valid values:
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "net_type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TrafficQosQueueArgs', 'TrafficQosQueue']

@pulumi.input_type
class TrafficQosQueueArgs:
    def __init__(__self__, *,
                 qos_id: pulumi.Input[str],
                 queue_type: pulumi.Input[str],
                 bandwidth_percent: Optional[pulumi.Input[str]] = None,
                 queue_description: Optional[pulumi.Input[str]] = None,
                 queue_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TrafficQosQueue resource.
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_type: QoS queue type, value:
               - **High**: High priority queue.
               - **Medium**: Normal priority queue.
               - **Default**: the Default priority queue.
               > **NOTE:**  Default priority queue cannot be created.
        :param pulumi.Input[str] bandwidth_percent: QoS queue bandwidth percentage.
               
               - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
               - When the QoS queue type is **Default**, this field is "-".
        :param pulumi.Input[str] queue_description: The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_name: The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        pulumi.set(__self__, "qos_id", qos_id)
        pulumi.set(__self__, "queue_type", queue_type)
        if bandwidth_percent is not None:
            pulumi.set(__self__, "bandwidth_percent", bandwidth_percent)
        if queue_description is not None:
            pulumi.set(__self__, "queue_description", queue_description)
        if queue_name is not None:
            pulumi.set(__self__, "queue_name", queue_name)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Input[str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter(name="queueType")
    def queue_type(self) -> pulumi.Input[str]:
        """
        QoS queue type, value:
        - **High**: High priority queue.
        - **Medium**: Normal priority queue.
        - **Default**: the Default priority queue.
        > **NOTE:**  Default priority queue cannot be created.
        """
        return pulumi.get(self, "queue_type")

    @queue_type.setter
    def queue_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "queue_type", value)

    @property
    @pulumi.getter(name="bandwidthPercent")
    def bandwidth_percent(self) -> Optional[pulumi.Input[str]]:
        """
        QoS queue bandwidth percentage.

        - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
        - When the QoS queue type is **Default**, this field is "-".
        """
        return pulumi.get(self, "bandwidth_percent")

    @bandwidth_percent.setter
    def bandwidth_percent(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth_percent", value)

    @property
    @pulumi.getter(name="queueDescription")
    def queue_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_description")

    @queue_description.setter
    def queue_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_description", value)

    @property
    @pulumi.getter(name="queueName")
    def queue_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_name")

    @queue_name.setter
    def queue_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_name", value)


@pulumi.input_type
class _TrafficQosQueueState:
    def __init__(__self__, *,
                 bandwidth_percent: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_description: Optional[pulumi.Input[str]] = None,
                 queue_id: Optional[pulumi.Input[str]] = None,
                 queue_name: Optional[pulumi.Input[str]] = None,
                 queue_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TrafficQosQueue resources.
        :param pulumi.Input[str] bandwidth_percent: QoS queue bandwidth percentage.
               
               - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
               - When the QoS queue type is **Default**, this field is "-".
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_description: The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[str] queue_name: The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_type: QoS queue type, value:
               - **High**: High priority queue.
               - **Medium**: Normal priority queue.
               - **Default**: the Default priority queue.
               > **NOTE:**  Default priority queue cannot be created.
        :param pulumi.Input[str] status: The status of the resource.
        """
        if bandwidth_percent is not None:
            pulumi.set(__self__, "bandwidth_percent", bandwidth_percent)
        if qos_id is not None:
            pulumi.set(__self__, "qos_id", qos_id)
        if queue_description is not None:
            pulumi.set(__self__, "queue_description", queue_description)
        if queue_id is not None:
            pulumi.set(__self__, "queue_id", queue_id)
        if queue_name is not None:
            pulumi.set(__self__, "queue_name", queue_name)
        if queue_type is not None:
            pulumi.set(__self__, "queue_type", queue_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="bandwidthPercent")
    def bandwidth_percent(self) -> Optional[pulumi.Input[str]]:
        """
        QoS queue bandwidth percentage.

        - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
        - When the QoS queue type is **Default**, this field is "-".
        """
        return pulumi.get(self, "bandwidth_percent")

    @bandwidth_percent.setter
    def bandwidth_percent(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth_percent", value)

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @qos_id.setter
    def qos_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_id", value)

    @property
    @pulumi.getter(name="queueDescription")
    def queue_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_description")

    @queue_description.setter
    def queue_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_description", value)

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> Optional[pulumi.Input[str]]:
        """
        The QoS queue ID.
        """
        return pulumi.get(self, "queue_id")

    @queue_id.setter
    def queue_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_id", value)

    @property
    @pulumi.getter(name="queueName")
    def queue_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_name")

    @queue_name.setter
    def queue_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_name", value)

    @property
    @pulumi.getter(name="queueType")
    def queue_type(self) -> Optional[pulumi.Input[str]]:
        """
        QoS queue type, value:
        - **High**: High priority queue.
        - **Medium**: Normal priority queue.
        - **Default**: the Default priority queue.
        > **NOTE:**  Default priority queue cannot be created.
        """
        return pulumi.get(self, "queue_type")

    @queue_type.setter
    def queue_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "queue_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class TrafficQosQueue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_percent: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_description: Optional[pulumi.Input[str]] = None,
                 queue_name: Optional[pulumi.Input[str]] = None,
                 queue_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Traffic Qos Queue resource. Express Connect Traffic QoS Queue.

        For information about Express Connect Traffic Qos Queue and how to use it, see [What is Traffic Qos Queue](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQosQueue).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        create_qos_queue = alicloud.expressconnect.TrafficQosQueue("createQosQueue",
            qos_id=create_qos.id,
            bandwidth_percent="60",
            queue_description="terraform-example",
            queue_name=name,
            queue_type="Medium")
        ```

        ## Import

        Express Connect Traffic Qos Queue can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosQueue:TrafficQosQueue example <qos_id>:<queue_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bandwidth_percent: QoS queue bandwidth percentage.
               
               - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
               - When the QoS queue type is **Default**, this field is "-".
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_description: The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_name: The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_type: QoS queue type, value:
               - **High**: High priority queue.
               - **Medium**: Normal priority queue.
               - **Default**: the Default priority queue.
               > **NOTE:**  Default priority queue cannot be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficQosQueueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Traffic Qos Queue resource. Express Connect Traffic QoS Queue.

        For information about Express Connect Traffic Qos Queue and how to use it, see [What is Traffic Qos Queue](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQosQueue).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        associate_qos = alicloud.expressconnect.TrafficQosAssociation("associateQos",
            instance_id=default.ids[1],
            qos_id=create_qos.id,
            instance_type="PHYSICALCONNECTION")
        create_qos_queue = alicloud.expressconnect.TrafficQosQueue("createQosQueue",
            qos_id=create_qos.id,
            bandwidth_percent="60",
            queue_description="terraform-example",
            queue_name=name,
            queue_type="Medium")
        ```

        ## Import

        Express Connect Traffic Qos Queue can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQosQueue:TrafficQosQueue example <qos_id>:<queue_id>
        ```

        :param str resource_name: The name of the resource.
        :param TrafficQosQueueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficQosQueueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth_percent: Optional[pulumi.Input[str]] = None,
                 qos_id: Optional[pulumi.Input[str]] = None,
                 queue_description: Optional[pulumi.Input[str]] = None,
                 queue_name: Optional[pulumi.Input[str]] = None,
                 queue_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficQosQueueArgs.__new__(TrafficQosQueueArgs)

            __props__.__dict__["bandwidth_percent"] = bandwidth_percent
            if qos_id is None and not opts.urn:
                raise TypeError("Missing required property 'qos_id'")
            __props__.__dict__["qos_id"] = qos_id
            __props__.__dict__["queue_description"] = queue_description
            __props__.__dict__["queue_name"] = queue_name
            if queue_type is None and not opts.urn:
                raise TypeError("Missing required property 'queue_type'")
            __props__.__dict__["queue_type"] = queue_type
            __props__.__dict__["queue_id"] = None
            __props__.__dict__["status"] = None
        super(TrafficQosQueue, __self__).__init__(
            'alicloud:expressconnect/trafficQosQueue:TrafficQosQueue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth_percent: Optional[pulumi.Input[str]] = None,
            qos_id: Optional[pulumi.Input[str]] = None,
            queue_description: Optional[pulumi.Input[str]] = None,
            queue_id: Optional[pulumi.Input[str]] = None,
            queue_name: Optional[pulumi.Input[str]] = None,
            queue_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'TrafficQosQueue':
        """
        Get an existing TrafficQosQueue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bandwidth_percent: QoS queue bandwidth percentage.
               
               - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
               - When the QoS queue type is **Default**, this field is "-".
        :param pulumi.Input[str] qos_id: The QoS policy ID.
        :param pulumi.Input[str] queue_description: The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_id: The QoS queue ID.
        :param pulumi.Input[str] queue_name: The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] queue_type: QoS queue type, value:
               - **High**: High priority queue.
               - **Medium**: Normal priority queue.
               - **Default**: the Default priority queue.
               > **NOTE:**  Default priority queue cannot be created.
        :param pulumi.Input[str] status: The status of the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficQosQueueState.__new__(_TrafficQosQueueState)

        __props__.__dict__["bandwidth_percent"] = bandwidth_percent
        __props__.__dict__["qos_id"] = qos_id
        __props__.__dict__["queue_description"] = queue_description
        __props__.__dict__["queue_id"] = queue_id
        __props__.__dict__["queue_name"] = queue_name
        __props__.__dict__["queue_type"] = queue_type
        __props__.__dict__["status"] = status
        return TrafficQosQueue(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bandwidthPercent")
    def bandwidth_percent(self) -> pulumi.Output[str]:
        """
        QoS queue bandwidth percentage.

        - When the QoS queue type is **Medium**, this field must be entered. Valid values: 1 to 100.
        - When the QoS queue type is **Default**, this field is "-".
        """
        return pulumi.get(self, "bandwidth_percent")

    @property
    @pulumi.getter(name="qosId")
    def qos_id(self) -> pulumi.Output[str]:
        """
        The QoS policy ID.
        """
        return pulumi.get(self, "qos_id")

    @property
    @pulumi.getter(name="queueDescription")
    def queue_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the QoS queue.  The length is 0 to 256 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_description")

    @property
    @pulumi.getter(name="queueId")
    def queue_id(self) -> pulumi.Output[str]:
        """
        The QoS queue ID.
        """
        return pulumi.get(self, "queue_id")

    @property
    @pulumi.getter(name="queueName")
    def queue_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the QoS queue.  The length is 0 to 128 characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "queue_name")

    @property
    @pulumi.getter(name="queueType")
    def queue_type(self) -> pulumi.Output[str]:
        """
        QoS queue type, value:
        - **High**: High priority queue.
        - **Medium**: Normal priority queue.
        - **Default**: the Default priority queue.
        > **NOTE:**  Default priority queue cannot be created.
        """
        return pulumi.get(self, "queue_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ConnectionArgs', 'Connection']

@pulumi.input_type
class ConnectionArgs:
    def __init__(__self__, *,
                 connection_string_prefix: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 port: pulumi.Input[str]):
        """
        The set of arguments for constructing a Connection resource.
        :param pulumi.Input[str] connection_string_prefix: The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port: The service port number of the instance.
        """
        pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Input[str]:
        """
        The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: pulumi.Input[str]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def port(self) -> pulumi.Input[str]:
        """
        The service port number of the instance.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[str]):
        pulumi.set(self, "port", value)


@pulumi.input_type
class _ConnectionState:
    def __init__(__self__, *,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 connection_string_prefix: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Connection resources.
        :param pulumi.Input[str] connection_string: The public connection string of KVStore DBInstance.
        :param pulumi.Input[str] connection_string_prefix: The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port: The service port number of the instance.
        """
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if connection_string_prefix is not None:
            pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The public connection string of KVStore DBInstance.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        """
        The service port number of the instance.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)


class Connection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Operate the public network ip of the specified resource. How to use it, see [What is Resource Alicloud KVStore Connection](https://www.alibabacloud.com/help/doc-detail/125795.htm).

        > **NOTE:** Available since v1.101.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.kvstore.get_zones()
        default_get_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default.zones[0].id)
        default_instance = alicloud.kvstore.Instance("default",
            db_instance_name=name,
            vswitch_id=default_switch.id,
            resource_group_id=default_get_resource_groups.ids[0],
            zone_id=default.zones[0].id,
            instance_class="redis.master.large.default",
            instance_type="Redis",
            engine_version="5.0",
            security_ips=["10.23.12.24"],
            config={
                "appendonly": "yes",
                "lazyfree-lazy-eviction": "yes",
            },
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_connection = alicloud.kvstore.Connection("default",
            connection_string_prefix="exampleconnection",
            instance_id=default_instance.id,
            port="6370")
        ```

        ## Import

        KVStore connection can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kvstore/connection:Connection example r-abc12345678
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_string_prefix: The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port: The service port number of the instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Operate the public network ip of the specified resource. How to use it, see [What is Resource Alicloud KVStore Connection](https://www.alibabacloud.com/help/doc-detail/125795.htm).

        > **NOTE:** Available since v1.101.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.kvstore.get_zones()
        default_get_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default.zones[0].id)
        default_instance = alicloud.kvstore.Instance("default",
            db_instance_name=name,
            vswitch_id=default_switch.id,
            resource_group_id=default_get_resource_groups.ids[0],
            zone_id=default.zones[0].id,
            instance_class="redis.master.large.default",
            instance_type="Redis",
            engine_version="5.0",
            security_ips=["10.23.12.24"],
            config={
                "appendonly": "yes",
                "lazyfree-lazy-eviction": "yes",
            },
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_connection = alicloud.kvstore.Connection("default",
            connection_string_prefix="exampleconnection",
            instance_id=default_instance.id,
            port="6370")
        ```

        ## Import

        KVStore connection can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kvstore/connection:Connection example r-abc12345678
        ```

        :param str resource_name: The name of the resource.
        :param ConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectionArgs.__new__(ConnectionArgs)

            if connection_string_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'connection_string_prefix'")
            __props__.__dict__["connection_string_prefix"] = connection_string_prefix
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if port is None and not opts.urn:
                raise TypeError("Missing required property 'port'")
            __props__.__dict__["port"] = port
            __props__.__dict__["connection_string"] = None
        super(Connection, __self__).__init__(
            'alicloud:kvstore/connection:Connection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_string: Optional[pulumi.Input[str]] = None,
            connection_string_prefix: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            port: Optional[pulumi.Input[str]] = None) -> 'Connection':
        """
        Get an existing Connection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connection_string: The public connection string of KVStore DBInstance.
        :param pulumi.Input[str] connection_string_prefix: The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port: The service port number of the instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectionState.__new__(_ConnectionState)

        __props__.__dict__["connection_string"] = connection_string
        __props__.__dict__["connection_string_prefix"] = connection_string_prefix
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["port"] = port
        return Connection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> pulumi.Output[str]:
        """
        The public connection string of KVStore DBInstance.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Output[str]:
        """
        The prefix of the public endpoint. The prefix can be 8 to 64 characters in length, and can contain lowercase letters and digits. It must start with a lowercase letter.
        """
        return pulumi.get(self, "connection_string_prefix")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[str]:
        """
        The service port number of the instance.
        """
        return pulumi.get(self, "port")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorSessionsResult',
    'AwaitableGetTrafficMirrorSessionsResult',
    'get_traffic_mirror_sessions',
    'get_traffic_mirror_sessions_output',
]

@pulumi.output_type
class GetTrafficMirrorSessionsResult:
    """
    A collection of values returned by getTrafficMirrorSessions.
    """
    def __init__(__self__, enabled=None, id=None, ids=None, name_regex=None, names=None, output_file=None, priority=None, sessions=None, status=None, traffic_mirror_filter_id=None, traffic_mirror_session_name=None, traffic_mirror_source_id=None, traffic_mirror_target_id=None):
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if sessions and not isinstance(sessions, list):
            raise TypeError("Expected argument 'sessions' to be a list")
        pulumi.set(__self__, "sessions", sessions)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if traffic_mirror_filter_id and not isinstance(traffic_mirror_filter_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_session_name and not isinstance(traffic_mirror_session_name, str):
            raise TypeError("Expected argument 'traffic_mirror_session_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_session_name", traffic_mirror_session_name)
        if traffic_mirror_source_id and not isinstance(traffic_mirror_source_id, str):
            raise TypeError("Expected argument 'traffic_mirror_source_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_source_id", traffic_mirror_source_id)
        if traffic_mirror_target_id and not isinstance(traffic_mirror_target_id, str):
            raise TypeError("Expected argument 'traffic_mirror_target_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[bool]:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def priority(self) -> Optional[int]:
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def sessions(self) -> Sequence['outputs.GetTrafficMirrorSessionsSessionResult']:
        return pulumi.get(self, "sessions")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> Optional[str]:
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorSessionName")
    def traffic_mirror_session_name(self) -> Optional[str]:
        return pulumi.get(self, "traffic_mirror_session_name")

    @property
    @pulumi.getter(name="trafficMirrorSourceId")
    def traffic_mirror_source_id(self) -> Optional[str]:
        return pulumi.get(self, "traffic_mirror_source_id")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> Optional[str]:
        return pulumi.get(self, "traffic_mirror_target_id")


class AwaitableGetTrafficMirrorSessionsResult(GetTrafficMirrorSessionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorSessionsResult(
            enabled=self.enabled,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            priority=self.priority,
            sessions=self.sessions,
            status=self.status,
            traffic_mirror_filter_id=self.traffic_mirror_filter_id,
            traffic_mirror_session_name=self.traffic_mirror_session_name,
            traffic_mirror_source_id=self.traffic_mirror_source_id,
            traffic_mirror_target_id=self.traffic_mirror_target_id)


def get_traffic_mirror_sessions(enabled: Optional[bool] = None,
                                ids: Optional[Sequence[str]] = None,
                                name_regex: Optional[str] = None,
                                output_file: Optional[str] = None,
                                priority: Optional[int] = None,
                                status: Optional[str] = None,
                                traffic_mirror_filter_id: Optional[str] = None,
                                traffic_mirror_session_name: Optional[str] = None,
                                traffic_mirror_source_id: Optional[str] = None,
                                traffic_mirror_target_id: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorSessionsResult:
    """
    This data source provides the Vpc Traffic Mirror Sessions of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.142.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"])
    pulumi.export("vpcTrafficMirrorSessionId1", ids.sessions[0].id)
    name_regex = alicloud.vpc.get_traffic_mirror_sessions(name_regex="^my-TrafficMirrorSession")
    pulumi.export("vpcTrafficMirrorSessionId2", name_regex.sessions[0].id)
    enabled = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        enabled=False)
    pulumi.export("vpcTrafficMirrorSessionId3", enabled.sessions[0].id)
    priority = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        priority=1)
    pulumi.export("vpcTrafficMirrorSessionId4", priority.sessions[0].id)
    filter_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_filter_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId5", filter_id.sessions[0].id)
    session_name = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_session_name="example_value")
    pulumi.export("vpcTrafficMirrorSessionId6", session_name.sessions[0].id)
    source_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_source_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId7", source_id.sessions[0].id)
    target_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_target_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId8", target_id.sessions[0].id)
    status = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        status="Created")
    pulumi.export("vpcTrafficMirrorSessionId9", status.sessions[0].id)
    ```


    :param bool enabled: Specifies whether to enable traffic mirror sessions. default to `false`.
    :param Sequence[str] ids: A list of Traffic Mirror Session IDs.
    :param str name_regex: A regex string to filter results by Traffic Mirror Session name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int priority: The priority of the traffic mirror session. Valid values: `1` to `32766`. A smaller value indicates a higher priority. You cannot specify the same priority for traffic mirror sessions that are created in the same region with the same Alibaba Cloud account.
    :param str status: The state of the traffic mirror session. Valid values: `Creating`, `Created`, `Modifying` and `Deleting`.
    :param str traffic_mirror_filter_id: The ID of the filter.
    :param str traffic_mirror_session_name: The name of the traffic mirror session. The name must be `2` to `128` characters in length and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
    :param str traffic_mirror_source_id: The ID of the mirror source. You can specify only an elastic network interface (ENI) as the mirror source.
    :param str traffic_mirror_target_id: The ID of the mirror destination. You can specify only an ENI or a Server Load Balancer (SLB) instance as a mirror destination.
    """
    __args__ = dict()
    __args__['enabled'] = enabled
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['priority'] = priority
    __args__['status'] = status
    __args__['trafficMirrorFilterId'] = traffic_mirror_filter_id
    __args__['trafficMirrorSessionName'] = traffic_mirror_session_name
    __args__['trafficMirrorSourceId'] = traffic_mirror_source_id
    __args__['trafficMirrorTargetId'] = traffic_mirror_target_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getTrafficMirrorSessions:getTrafficMirrorSessions', __args__, opts=opts, typ=GetTrafficMirrorSessionsResult).value

    return AwaitableGetTrafficMirrorSessionsResult(
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        priority=pulumi.get(__ret__, 'priority'),
        sessions=pulumi.get(__ret__, 'sessions'),
        status=pulumi.get(__ret__, 'status'),
        traffic_mirror_filter_id=pulumi.get(__ret__, 'traffic_mirror_filter_id'),
        traffic_mirror_session_name=pulumi.get(__ret__, 'traffic_mirror_session_name'),
        traffic_mirror_source_id=pulumi.get(__ret__, 'traffic_mirror_source_id'),
        traffic_mirror_target_id=pulumi.get(__ret__, 'traffic_mirror_target_id'))
def get_traffic_mirror_sessions_output(enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                                       ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                       name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                       priority: Optional[pulumi.Input[Optional[int]]] = None,
                                       status: Optional[pulumi.Input[Optional[str]]] = None,
                                       traffic_mirror_filter_id: Optional[pulumi.Input[Optional[str]]] = None,
                                       traffic_mirror_session_name: Optional[pulumi.Input[Optional[str]]] = None,
                                       traffic_mirror_source_id: Optional[pulumi.Input[Optional[str]]] = None,
                                       traffic_mirror_target_id: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTrafficMirrorSessionsResult]:
    """
    This data source provides the Vpc Traffic Mirror Sessions of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.142.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"])
    pulumi.export("vpcTrafficMirrorSessionId1", ids.sessions[0].id)
    name_regex = alicloud.vpc.get_traffic_mirror_sessions(name_regex="^my-TrafficMirrorSession")
    pulumi.export("vpcTrafficMirrorSessionId2", name_regex.sessions[0].id)
    enabled = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        enabled=False)
    pulumi.export("vpcTrafficMirrorSessionId3", enabled.sessions[0].id)
    priority = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        priority=1)
    pulumi.export("vpcTrafficMirrorSessionId4", priority.sessions[0].id)
    filter_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_filter_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId5", filter_id.sessions[0].id)
    session_name = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_session_name="example_value")
    pulumi.export("vpcTrafficMirrorSessionId6", session_name.sessions[0].id)
    source_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_source_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId7", source_id.sessions[0].id)
    target_id = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        traffic_mirror_target_id="example_value")
    pulumi.export("vpcTrafficMirrorSessionId8", target_id.sessions[0].id)
    status = alicloud.vpc.get_traffic_mirror_sessions(ids=["example_id"],
        status="Created")
    pulumi.export("vpcTrafficMirrorSessionId9", status.sessions[0].id)
    ```


    :param bool enabled: Specifies whether to enable traffic mirror sessions. default to `false`.
    :param Sequence[str] ids: A list of Traffic Mirror Session IDs.
    :param str name_regex: A regex string to filter results by Traffic Mirror Session name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int priority: The priority of the traffic mirror session. Valid values: `1` to `32766`. A smaller value indicates a higher priority. You cannot specify the same priority for traffic mirror sessions that are created in the same region with the same Alibaba Cloud account.
    :param str status: The state of the traffic mirror session. Valid values: `Creating`, `Created`, `Modifying` and `Deleting`.
    :param str traffic_mirror_filter_id: The ID of the filter.
    :param str traffic_mirror_session_name: The name of the traffic mirror session. The name must be `2` to `128` characters in length and can contain digits, underscores (_), and hyphens (-). It must start with a letter.
    :param str traffic_mirror_source_id: The ID of the mirror source. You can specify only an elastic network interface (ENI) as the mirror source.
    :param str traffic_mirror_target_id: The ID of the mirror destination. You can specify only an ENI or a Server Load Balancer (SLB) instance as a mirror destination.
    """
    __args__ = dict()
    __args__['enabled'] = enabled
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['priority'] = priority
    __args__['status'] = status
    __args__['trafficMirrorFilterId'] = traffic_mirror_filter_id
    __args__['trafficMirrorSessionName'] = traffic_mirror_session_name
    __args__['trafficMirrorSourceId'] = traffic_mirror_source_id
    __args__['trafficMirrorTargetId'] = traffic_mirror_target_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getTrafficMirrorSessions:getTrafficMirrorSessions', __args__, opts=opts, typ=GetTrafficMirrorSessionsResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorSessionsResult(
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        priority=pulumi.get(__response__, 'priority'),
        sessions=pulumi.get(__response__, 'sessions'),
        status=pulumi.get(__response__, 'status'),
        traffic_mirror_filter_id=pulumi.get(__response__, 'traffic_mirror_filter_id'),
        traffic_mirror_session_name=pulumi.get(__response__, 'traffic_mirror_session_name'),
        traffic_mirror_source_id=pulumi.get(__response__, 'traffic_mirror_source_id'),
        traffic_mirror_target_id=pulumi.get(__response__, 'traffic_mirror_target_id')))
